#!/usr/bin/env perl
use strict;
use warnings;
use Geo::WeatherNWS;

my $Report = Geo::WeatherNWS::new();
$Report->getreport("kord");    # Chicago
print "Observation:   $Report->{obs}\n";
print "Station code:  $Report->{code}\n";
print "Day:           $Report->{day}\n";
print "Time:          $Report->{time}\n";
print "Temperature:   $Report->{temperature_f} degrees (F)\n";
print "Dewpoint:      $Report->{dewpoint_f} degrees (F)\n"
    if $Report->{dewpoint_f} ne "";
print "Windchill:     $Report->{windchill_f} degrees (F)\n"
    if $Report->{windchill_f} ne "";
print "Heat index:    $Report->{heat_index_f} degrees (F)\n"
    if $Report->{heat_index_f} ne "";
print "Air pressure:  $Report->{pressure_inhg} inches\n";
print "Cloud cover:   $Report->{cloudcover}\n";

